==> djs-systems-embedbuilder-4.0.4.tgz: package/README.md <==
<div class="heading" align="center">
  

  <h2>The simplest way to build complex Discord bots.</h2>
  <h3>Made by Rahuletto#0243 - Extremely optimized by audiro</h3>

</div>

---

<br>

<div class="badges" align="center">

[![Version](https://img.shields.io/npm/v/simply-djs.svg?style=for-the-badge)](https://www.npmjs.com/package/simply-djs)
[![Downloads](https://img.shields.io/npm/dt/simply-djs?style=for-the-badge)](https://www.npmjs.com/package/simply-djs)
[![CodeFactor](https://www.codefactor.io/repository/github/rahuletto/simply-djs/badge/v4.x.x?style=for-the-badge)](https://www.codefactor.io/repository/github/rahuletto/simply-djs/overview/v4.x.x)

[![Documentation](https://img.shields.io/badge/SimplyDJS-Documentation-406dbc?style=for-the-badge)](https://simplyd.js.org)
[![Support](https://img.shields.io/badge/Discord-Support-5865F2?style=for-the-badge&logo=discord)](https://discord.gg/3JzDV9T5Fn)

[![Support](https://invidget.switchblade.xyz/3JzDV9T5Fn)](https://discord.gg/3JzDV9T5Fn)

</div>

<div align="center">
  <h3>Now returning with v4 (DiscordJS v14 support)</h3>
  This was too late. But we will support v15 as soon as its released.
</div>

---

> Thank you `CyberJack#6350` for helping me

---

<br>

## 🖥️ <b>How to install ?</b>

```
npm install simply-djs
```

```
yarn add simply-djs
```

```
pnpm add simply-djs
```

---

# What's new 🎁

### Package 📦

- Converted to DiscordJS v14
- All new `strict` mode.
- Proper Typings and Commenting
- Embeds and Buttons are now customized easily yet making it all yours
- Names that just make sense
- Removed `credit` option
- DEPRECATED many functions. [Refer to docs](https://simplyd.js.org/docs/deprecated/renames/)
- Remade all systems and games (For efficient and optimized results)
- Fixed many many bugs

### Documentation 📖

- Redesigned UI
- Documented every thing possible
- New Examples
- New Outputs
- Very much optimized for every device
- Optimized performance
- Better Search engine.

### Typings 🔍

- Splitted every common types and options
- Unified options
- Better intellisense
- Commented every code
- Options now have documentation JSDoc

---

# 📄 [License](https://creativecommons.org/licenses/by-nc-nd/4.0/)

## You are free to:

- **Share:** Copy and redistribute the material in any medium or format

## Under the following terms:

- **Attribution:** You must give appropriate credit, provide a link to the license, and indicate if changes were made. You may do so in any reasonable manner, but not in any way that suggests the licensor endorses you or your use.

- **NonCommercial:** You may not use the material for commercial purposes.

- **NoDerivatives:** If you remix, transform, or build upon the material, you may not distribute the _modified_ material.

<img style="margin-bottom:-6px; width: 100px" src="https://mirrors.creativecommons.org/presskit/logos/cc.logo.large.png">

---

# 👥 Contact us/Support

[![Support](https://invidget.switchblade.xyz/3JzDV9T5Fn)](https://discord.gg/3JzDV9T5Fn)

==> djs-systems-embedbuilder-4.0.5.tgz: package/README.md <==
<div class="heading" align="center">
  

  <h2>The simplest way to build complex Discord bots.</h2>
  <h3>Optimized by audiro, made by Rahuletto#0243</h3>

</div>

---

<br>

<div class="badges" align="center">

[![Version](https://img.shields.io/npm/v/simply-djs.svg?style=for-the-badge)](https://www.npmjs.com/package/simply-djs)
[![Downloads](https://img.shields.io/npm/dt/simply-djs?style=for-the-badge)](https://www.npmjs.com/package/simply-djs)
[![CodeFactor](https://www.codefactor.io/repository/github/rahuletto/simply-djs/badge/v4.x.x?style=for-the-badge)](https://www.codefactor.io/repository/github/rahuletto/simply-djs/overview/v4.x.x)

[![Documentation](https://img.shields.io/badge/SimplyDJS-Documentation-406dbc?style=for-the-badge)](https://simplyd.js.org)
[![Support](https://audiro.discowd.com/Discord_TuRdmQM3pE.png)](https://discord.gg/3JzDV9T5Fn)

[![Support](https://invidget.switchblade.xyz/3JzDV9T5Fn)](https://discord.gg/3JzDV9T5Fn)

</div>

<div align="center">
  <h3>Now returning with v4 (DiscordJS v14 support)</h3>
  This was too late. But we will support v15 as soon as its released.
</div>

---

> Thank you `CyberJack#6350` for helping me

---

<br>

## 🖥️ <b>How to install ?</b>

```
npm install simply-djs
```

```
yarn add simply-djs
```

```
pnpm add simply-djs
```

---

# What's new 🎁

### Package 📦

- Converted to DiscordJS v14
- All new `strict` mode.
- Proper Typings and Commenting
- Embeds and Buttons are now customized easily yet making it all yours
- Names that just make sense
- Removed `credit` option
- DEPRECATED many functions. [Refer to docs](https://simplyd.js.org/docs/deprecated/renames/)
- Remade all systems and games (For efficient and optimized results)
- Fixed many many bugs

### Documentation 📖

- Redesigned UI
- Documented every thing possible
- New Examples
- New Outputs
- Very much optimized for every device
- Optimized performance
- Better Search engine.

### Typings 🔍

- Splitted every common types and options
- Unified options
- Better intellisense
- Commented every code
- Options now have documentation JSDoc

---

# 📄 [License](https://creativecommons.org/licenses/by-nc-nd/4.0/)

## You are free to:

- **Share:** Copy and redistribute the material in any medium or format

## Under the following terms:

- **Attribution:** You must give appropriate credit, provide a link to the license, and indicate if changes were made. You may do so in any reasonable manner, but not in any way that suggests the licensor endorses you or your use.

- **NonCommercial:** You may not use the material for commercial purposes.

- **NoDerivatives:** If you remix, transform, or build upon the material, you may not distribute the _modified_ material.

<img style="margin-bottom:-6px; width: 100px" src="https://mirrors.creativecommons.org/presskit/logos/cc.logo.large.png">

---

# 👥 Contact us/Support

[![Support](https://invidget.switchblade.xyz/3JzDV9T5Fn)](https://discord.gg/3JzDV9T5Fn)
